==> jc-1.4.0.tar.gz: gnu/java/rmi/server/RMIObjectInputStream.h <==
// public class gnu.java.rmi.server.RMIObjectInputStream

// class file dependencies
// @dep_class 2da16ed0039378d9 gnu_java_rmi_server_RMIObjectInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class 4008cd22e279a8c3 java_io_ObjectInputStream
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_io_ObjectInputStream

#include "java/io/ObjectInputStream.h"

#ifndef _JC_gnu_java_rmi_server_RMIObjectInputStream_H_
#define _JC_gnu_java_rmi_server_RMIObjectInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_ObjectStreamClass$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_refs	_jc_gnu_java_rmi_server_RMIObjectInputStream$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_nonrefs	_jc_gnu_java_rmi_server_RMIObjectInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectInputStream$refs	_jc_gnu_java_rmi_server_RMIObjectInputStream$refs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectInputStream$nonrefs	_jc_gnu_java_rmi_server_RMIObjectInputStream$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object	_jc_gnu_java_rmi_server_RMIObjectInputStream$object;

typedef const struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vmethods	_jc_gnu_java_rmi_server_RMIObjectInputStream$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vtable	_jc_gnu_java_rmi_server_RMIObjectInputStream$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vtype	_jc_gnu_java_rmi_server_RMIObjectInputStream$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIObjectInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_java_io_InputStream$object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_rmi_server_RMIObjectInputStream$method$getAnnotation$74e25509df28bb55(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_java_rmi_server_RMIObjectInputStream$method$readValue$c33fe4dc99ad8331(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_java_lang_Class$object *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_rmi_server_RMIObjectInputStream$method$resolveClass$4972e952261d1134(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_java_io_ObjectStreamClass$object *);
extern struct _jc_java_lang_Class$object *_jc_gnu_java_rmi_server_RMIObjectInputStream$method$resolveProxyClass$dcad229a82f5696c(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_object_array *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectInputStream$method_info$getAnnotation$74e25509df28bb55;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectInputStream$method_info$readValue$c33fe4dc99ad8331;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectInputStream$method_info$resolveClass$4972e952261d1134;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectInputStream$method_info$resolveProxyClass$dcad229a82f5696c;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vmethods {
	struct _jc_java_lang_Object$object	*(*getAnnotation$74e25509df28bb55)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *);
	struct _jc_java_lang_Object$object	*(*readValue$c33fe4dc99ad8331)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_java_lang_Class$object *);
	struct _jc_java_lang_Class$object	*(*resolveClass$4972e952261d1134)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_java_io_ObjectStreamClass$object *);
	struct _jc_java_lang_Class$object	*(*resolveProxyClass$dcad229a82f5696c)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_object_array *);
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_ObjectInputStream$vmethods	java_io_ObjectInputStream;
	_jc_gnu_java_rmi_server_RMIObjectInputStream$vmethods	gnu_java_rmi_server_RMIObjectInputStream;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIObjectInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$refs {
    _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_refs	gnu_java_rmi_server_RMIObjectInputStream;
    _jc_java_io_ObjectInputStream$sub_refs	java_io_ObjectInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_ObjectInputStream$sub_nonrefs	java_io_ObjectInputStream;
    _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_nonrefs	gnu_java_rmi_server_RMIObjectInputStream;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object {
	_jc_gnu_java_rmi_server_RMIObjectInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIObjectInputStream$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIObjectInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIObjectInputStream$vtype _jc_gnu_java_rmi_server_RMIObjectInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIObjectInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIObjectInputStream$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIObjectInputStream_H_ */

==> jc-1.4.5.tar.gz: gnu/java/rmi/server/RMIObjectInputStream.h <==
// public class gnu.java.rmi.server.RMIObjectInputStream

// class file dependencies
// @dep_class 2da16ed0039378d9 gnu_java_rmi_server_RMIObjectInputStream
// @dep_class 66aea4d152614ac4 java_io_InputStream
// @dep_class d8257ba70d6d4735 java_io_ObjectInputStream
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_io_ObjectInputStream

#include "java/io/ObjectInputStream.h"

#ifndef _JC_gnu_java_rmi_server_RMIObjectInputStream_H_
#define _JC_gnu_java_rmi_server_RMIObjectInputStream_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_io_ObjectStreamClass$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_refs	_jc_gnu_java_rmi_server_RMIObjectInputStream$sub_refs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_nonrefs	_jc_gnu_java_rmi_server_RMIObjectInputStream$sub_nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectInputStream$refs	_jc_gnu_java_rmi_server_RMIObjectInputStream$refs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectInputStream$nonrefs	_jc_gnu_java_rmi_server_RMIObjectInputStream$nonrefs;
typedef struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object	_jc_gnu_java_rmi_server_RMIObjectInputStream$object;

typedef const struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vmethods	_jc_gnu_java_rmi_server_RMIObjectInputStream$vmethods;
typedef const struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vtable	_jc_gnu_java_rmi_server_RMIObjectInputStream$vtable;
typedef const struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vtype	_jc_gnu_java_rmi_server_RMIObjectInputStream$vtype;

// Constructors
extern void _jc_gnu_java_rmi_server_RMIObjectInputStream$method$_init$3887600c17c5e554(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_gnu_java_rmi_server_RMIObjectInputStream$method$getAnnotation$74e25509df28bb55(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_java_rmi_server_RMIObjectInputStream$method$readValue$c33fe4dc99ad8331(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_rmi_server_RMIObjectInputStream$method$resolveClass$4972e952261d1134(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_java_io_ObjectStreamClass$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Class$object *_jc_gnu_java_rmi_server_RMIObjectInputStream$method$resolveProxyClass$dcad229a82f5696c(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_object_array *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectInputStream$method_info$getAnnotation$74e25509df28bb55;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectInputStream$method_info$readValue$c33fe4dc99ad8331;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectInputStream$method_info$resolveClass$4972e952261d1134;
extern _jc_method _jc_gnu_java_rmi_server_RMIObjectInputStream$method_info$resolveProxyClass$dcad229a82f5696c;

// Virtual methods structure
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vmethods {
	struct _jc_java_lang_Object$object	*(*getAnnotation$74e25509df28bb55)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*readValue$c33fe4dc99ad8331)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*resolveClass$4972e952261d1134)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_java_io_ObjectStreamClass$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Class$object	*(*resolveProxyClass$dcad229a82f5696c)(_jc_env *, struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object *, struct _jc_object_array *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_io_InputStream$vmethods	java_io_InputStream;
	_jc_java_io_ObjectInputStream$vmethods	java_io_ObjectInputStream;
	_jc_gnu_java_rmi_server_RMIObjectInputStream$vmethods	gnu_java_rmi_server_RMIObjectInputStream;
};

// Vtype
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$vtype {
	_jc_type			type;
	_jc_gnu_java_rmi_server_RMIObjectInputStream$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$refs {
    _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_refs	gnu_java_rmi_server_RMIObjectInputStream;
    _jc_java_io_ObjectInputStream$sub_refs	java_io_ObjectInputStream;
    _jc_java_io_InputStream$sub_refs	java_io_InputStream;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_io_InputStream$sub_nonrefs	java_io_InputStream;
    _jc_java_io_ObjectInputStream$sub_nonrefs	java_io_ObjectInputStream;
    _jc_gnu_java_rmi_server_RMIObjectInputStream$sub_nonrefs	gnu_java_rmi_server_RMIObjectInputStream;
};

// Object instance structure
struct _jc_gnu_java_rmi_server_RMIObjectInputStream$object {
	_jc_gnu_java_rmi_server_RMIObjectInputStream$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_rmi_server_RMIObjectInputStream$vtype	*vtype;
	_jc_gnu_java_rmi_server_RMIObjectInputStream$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_rmi_server_RMIObjectInputStream$vtype _jc_gnu_java_rmi_server_RMIObjectInputStream$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_rmi_server_RMIObjectInputStream, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_rmi_server_RMIObjectInputStream$class_object;

#endif	/* _JC_gnu_java_rmi_server_RMIObjectInputStream_H_ */
